package com.lzmispt.data.resource.service.developconfig.impl;

package .tmp;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.lzmispt.core.entity.coreconst.CoreConst;
import com.lzmispt.core.entity.dto.authorize.SysTokenDTO;
import com.lzmispt.core.entity.dto.authorize.UserInfoDTO;
import com.lzmispt.core.entity.vo.authorize.TokenInfoVO;
import com.lzmispt.core.entity.vo.login.LoginVO;
import com.lzmispt.core.entity.vo.user.UserVO;
import com.lzmispt.core.service.authorize.IAuthorize;
import com.lzmispt.core.service.user.IUser;
import com.lzmispt.data.center.entity.dto.resource.file.FileRootPathDTO;
import com.lzmispt.data.center.entity.enums.StatusCodeEnum;
import com.lzmispt.data.center.entity.vo.resource.developconfig.DevelopConfigVO;
import com.lzmispt.data.center.entity.vo.resource.file.FileRootPathVO;
import com.lzmispt.data.resource.dao.developconfig.impl.DevelopConfigDaoImpl;
import com.lzmispt.data.resource.dao.file.IFileInfoTableDao;
import com.lzmispt.data.resource.entity.dto.developconfig.TransferConfigDTO;
import com.lzmispt.data.resource.entity.po.developconfig.DevelopConfigPO;
import com.lzmispt.data.resource.entity.vo.developconfig.TransferConfigVO;
import com.lzmispt.data.resource.service.developconfig.ITransferConfig;
import com.lzmispt.dcbase.ServiceUtil;
import com.lzmispt.dcbase.database.IManage;
import com.lzmispt.dcbase.dcconst.DCConst;
import com.lzmispt.dcbase.util.TokenUtil;
import com.lzmispt.framework.entity.dto.useragent.UserAgentDTO;
import com.lzmispt.framework.entity.entity.ResultEntity;
import com.lzmispt.framework.utils.SessionUtil;
import com.lzmispt.framework.utils.WorkerId;
import java.util.Date;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class ManageTransferConfigImpl implements ITransferConfig, IManage {
  @Autowired
  IUser iUser;
  
  @Autowired
  private IAuthorize authorize;
  
  @Autowired
  private DevelopConfigDaoImpl developConfigDao;
  
  private final Integer clientType = Integer.valueOf(0);
  
  public String getDefaultCode() {
    return "Manage";
  }
  
  public ResultEntity<TransferConfigVO> getTransferInfo(TransferConfigDTO transferConfigDTO) {
    String loginName = transferConfigDTO.getLoginName();
    ResultEntity<UserVO> userInfoResult = this.iUser.getUserByLoginName(loginName);
    if (0 != userInfoResult.getCode().intValue())
      return ResultEntity.errorMessage(userInfoResult.getCode(), userInfoResult.getMsg()); 
    UserVO userInfo = (UserVO)userInfoResult.getObj();
    ResultEntity<TokenInfoVO> tokenInfoObj = this.authorize.getTokenInfo(userInfo.getMangerUserId(), this.clientType);
    TokenInfoVO tokenInfoVO = (TokenInfoVO)tokenInfoObj.getObj();
    if (null == tokenInfoVO) {
      SysTokenDTO<UserAgentDTO> sysTokenDTO = getSysTokenDTO(userInfo);
      ResultEntity<TokenInfoVO> authorizeTokenInfoObj = this.authorize.authorizeTokenId(sysTokenDTO);
      if (0 != authorizeTokenInfoObj.getCode().intValue())
        return ResultEntity.errorMessage(authorizeTokenInfoObj.getCode(), authorizeTokenInfoObj.getMsg()); 
      tokenInfoVO = (TokenInfoVO)authorizeTokenInfoObj.getObj();
    } 
    TransferConfigVO transferConfigVO = new TransferConfigVO();
    LoginVO loginInfo = new LoginVO();
    BeanUtils.copyProperties(tokenInfoVO, loginInfo);
    loginInfo.setLoginName(userInfo.getLoginName());
    loginInfo.setUserName(userInfo.getUserName());
    transferConfigVO.setLoginInfo(loginInfo);
    return ResultEntity.successMessage(transferConfigVO);
  }
  
  public ResultEntity<Boolean> setFileRootPath(FileRootPathDTO fileRootPathDTO, String platCode, String tokenId) {
    ResultEntity<Boolean> booleanResultEntity = setDevelopConfig(fileRootPathDTO, platCode, tokenId);
    if (booleanResultEntity.getCode().intValue() != 0)
      return booleanResultEntity; 
    IFileInfoTableDao fileInfoTableDao = (IFileInfoTableDao)ServiceUtil.getFileInfoTableDao(platCode, IFileInfoTableDao.class);
    fileInfoTableDao.updateAllFileRootPath(fileRootPathDTO.getFileRootPath());
    return ResultEntity.successMessage(Boolean.valueOf(true));
  }
  
  public ResultEntity<FileRootPathVO> getFileRootPath(String platCode) {
    FileRootPathVO fileRootPathVO = new FileRootPathVO();
    DevelopConfigPO configPO = this.developConfigDao.getDevelopConfig(platCode);
    if (configPO == null) {
      fileRootPathVO.setFileRootPath(null);
    } else {
      JSONObject config = JSONObject.parseObject(configPO.getConfigPlatJson());
      if (config == null) {
        fileRootPathVO.setFileRootPath(null);
      } else {
        fileRootPathVO.setFileRootPath(config.getString("fileRootPath"));
      } 
    } 
    return ResultEntity.successMessage(fileRootPathVO);
  }
  
  public ResultEntity<DevelopConfigVO> getDevelopConfig(String platCode) {
    DevelopConfigPO configPO = this.developConfigDao.getDevelopConfig(platCode);
    if (configPO != null) {
      DevelopConfigVO developConfigVO = new DevelopConfigVO();
      BeanUtils.copyProperties(configPO, developConfigVO);
      return ResultEntity.successMessage(developConfigVO);
    } 
    return ResultEntity.successMessage(null);
  }
  
  private SysTokenDTO<UserAgentDTO> getSysTokenDTO(UserVO userInfo) {
    SysTokenDTO<UserAgentDTO> sysTokenParam = new SysTokenDTO();
    sysTokenParam.setClientType(this.clientType);
    sysTokenParam.setUserId(userInfo.getMangerUserId());
    sysTokenParam.setLoginType(CoreConst.LoginType.DATA_CENTER_LOGIN);
    sysTokenParam.setLoginName(userInfo.getLoginName());
    sysTokenParam.setUserName(userInfo.getUserName());
    sysTokenParam.setOrganizationId(CoreConst.ORGANIZATION_ID);
    UserAgentDTO userAgentDTO = SessionUtil.getUserAgent();
    if (null != userAgentDTO) {
      sysTokenParam.setExtendObj(userAgentDTO);
      sysTokenParam.setClientIp(userAgentDTO.getClientMachine().getIp());
      if (null != userAgentDTO.getBrowser()) {
        String browser = userAgentDTO.getBrowser().getName() + userAgentDTO.getBrowser().getVersion();
        sysTokenParam.setBrowser(browser);
      } 
      sysTokenParam.setClientOS(userAgentDTO.getClientMachine().getOpSystem());
    } 
    sysTokenParam.setExtendObj(userAgentDTO);
    return sysTokenParam;
  }
  
  private ResultEntity<Boolean> setDevelopConfig(FileRootPathDTO fileRootPathDTO, String platCode, String tokenId) {
    DevelopConfigPO configPO = this.developConfigDao.getDevelopConfig(platCode);
    UserInfoDTO userInfo = TokenUtil.getUserInfoByTokenId(tokenId);
    String configJsonStr = JSON.toJSONString(fileRootPathDTO);
    if (configPO == null)
      return createNewConfig(configJsonStr, platCode, userInfo); 
    BeanUtils.copyProperties(userInfo, configPO);
    configPO.setUpdateTime(new Date());
    JSONObject configObj = JSONObject.parseObject(configPO.getConfigPlatJson());
    if (configObj == null) {
      configPO.setConfigPlatJson(JSON.toJSONString(fileRootPathDTO));
    } else {
      configObj.put("fileRootPath", fileRootPathDTO.getFileRootPath());
      configPO.setConfigPlatJson(configObj.toJSONString());
    } 
    boolean success = this.developConfigDao.updateDevelopConfig(configPO);
    if (success)
      return ResultEntity.successMessage(Boolean.valueOf(true)); 
    return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_SET_FILE_ROOT_PATH_FAILED.getCode()), StatusCodeEnum.DATA_RESOURCE_SET_FILE_ROOT_PATH_FAILED
        .getMessage());
  }
  
  private ResultEntity<Boolean> createNewConfig(String configJsonStr, String platCode, UserInfoDTO userInfoDTO) {
    DevelopConfigPO configPO = new DevelopConfigPO();
    BeanUtils.copyProperties(userInfoDTO, configPO);
    configPO.setConfigId((Long)WorkerId.getNextId(Long.class));
    configPO.setConfigPlatCode(platCode);
    configPO.setConfigPlatJson(configJsonStr);
    configPO.setCreateTime(new Date());
    configPO.setUpdateTime(new Date());
    configPO.setIsDelete(DCConst.FALSE);
    boolean success = this.developConfigDao.insertDevelopConfig(configPO);
    if (success)
      return ResultEntity.successMessage(Boolean.valueOf(true)); 
    return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_SET_FILE_ROOT_PATH_FAILED.getCode()), StatusCodeEnum.DATA_RESOURCE_SET_FILE_ROOT_PATH_FAILED
        .getMessage());
  }
}
